NoValidationInFastRound

Trait NoValidationInFastRound 

pub trait NoValidationInFastRound: VoteConstructionSites { }
Lemma (No validation vote in the fast round). A correct validator never casts a Validated vote in Round::Fast.

Proof. By VoteConstructionSites validation votes are produced only in the else branch of if round.is_fast() in ChainManager::create_vote, where round is the vote’s round. ∎

Implementors